function [spectrum, header] = hACQGetSpectrum(instrument, channelList, timeout)
%function [spectrum, header] = hACQGetSpectrum(instrument, channel, timeout)
%Returns spectrum data from one or more channels.
%
%parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%channelList - List of channels to return data for.  If this is empty, all
%channels will be returned.
%timeout - The requested timeout, in seconds.
%
%return values:
%spectrum - An N x M array uint16 data, where N is the number of dataPoints in the
%spectrum, and M is the number of channels for which data is returned.
%This data can be translated to dBm by getting the calibration offset and
%scale (see hACQGetPowerCalibrationInfo), and doing 
%calSpectrum = spectrum/scale + offset (also see plotSpectrum.m,
%plotMultipleSpectrum.m)
%header - A structure with the following fields:
    %length - Length of the header in bytes
    %version - header version
    %serialNumber - Serial number of the wavelength scan.
    %timeStamp - A time stop, corresponding to the number of seconds that
    %have passed since 00:00:00 1/1/1970.
    %startWavelength - The first wavelength in the scan.
    %wavelengthIncrement - The wavelength difference between neighboring
    %points in the spectrum.
    %numPoints - The number of data points in the spectrum.

if length(channelList) == 1
    argument = int2str(channelList);
else
    argument = '';
end

response = hCOMMExecuteCommand(instrument, '#GetSpectrum',...
    argument, 1, timeout);

dataBytes = response.content;
header.length = typecast(dataBytes(1:2),'uint16');
header.version = typecast(dataBytes(3:4),'uint16');
header.reserved = typecast(dataBytes(5:8),'uint32');
header.serialNumber = typecast(dataBytes(9:16),'uint64');
timeStampInt = typecast(dataBytes(17:20),'uint32');
timeStampFrac = typecast(dataBytes(21:24),'uint32');

header.timeStamp = uint64(double(timeStampInt)*1e9 + double(timeStampFrac));
header.startWavelength = typecast(dataBytes(25:32),'double');
header.wavelengthIncrement = typecast(dataBytes(33:40),'double');

header.numPoints = typecast(dataBytes(41:44),'uint32');
header.numChannels = typecast(dataBytes(45:46),'uint16');

header.reserved2 = typecast(dataBytes(47:48),'uint16');

if isempty(channelList)
    channelList = 1:header.numChannels;
end

spectrumDataBytes = dataBytes(int32(header.length) + 1:end);

spectrum = typecast(spectrumDataBytes,'uint16');
spectrum = reshape(spectrum,header.numPoints,[]);
if length(channelList) > 1
    spectrum = spectrum(:,channelList);
end

